.. image:: doc/content/logo.svg
    :height: 200px
    :width: 200px
.. image:: https://img.shields.io/pypi/l/lona.svg
    :alt: pypi.org
    :target: https://pypi.org/project/lona
.. image:: https://img.shields.io/travis/com/fscherf/lona/master.svg
    :alt: Travis branch
    :target: https://travis-ci.com/fscherf/lona
.. image:: https://img.shields.io/pypi/pyversions/lona.svg
    :alt: pypi.org
    :target: https://pypi.org/project/lona
.. image:: https://img.shields.io/pypi/v/lona.svg
    :alt: pypi.org
    :target: https://pypi.org/project/lona
.. image:: https://img.shields.io/codecov/c/github/fscherf/lona.svg
    :alt: codecov.io
    :target: https://codecov.io/gh/fscherf/lona/


Write responsive web apps in full python
